==> mobile_pos-1.1.1.tar.gz: lib/src/views/terminal/view_all_terminal_index.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/mobile_pos_sdk.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/raven_pay_fab.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button_loader.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/request_pos_index.dart';
import 'package:mobile_pos/src/views/terminal/widget/new_terminal_item.dart';
import 'package:mobile_pos/src/views/terminal/widget/pending_terminal_request_sheet.dart';
import 'package:mobile_pos/src/views/terminal/widget/terminal_item.dart';

class ViewAllTerminalIndex extends StatefulWidget {
  const ViewAllTerminalIndex({super.key});

  @override
  State<ViewAllTerminalIndex> createState() => _ViewAllTerminalIndexState();
}

class _ViewAllTerminalIndexState extends State<ViewAllTerminalIndex> {
  bool loading = true;
  List<Terminal> allTerminals = [];
  bool canRequestTerminal = true;
  bool updateBusinessInfo = false;

  void fetchTerminals({bool showLoading = true}) async {
    allTerminals.clear();
    if (showLoading) {
      loading = true;
    } else {
      loading = false;
    }
    updateBusinessInfo = await ApiRequests.getKYBStatus();
    await ApiRequests.fetchAppInfo();
    if (!mounted) {
      return;
    }
    final res = await ApiRequests.getUserBankBox();
    allTerminals.addAll(res);

    final res2 = await ApiRequests.getUserTerminalRequests();
    if (!mounted) {
      return;
    }
    canRequestTerminal = res2.isEmpty;
    allTerminals.addAll(res2);
    loading = false;
    setState(() {});
  }

  @override
  void initState() {
    super.initState();
    fetchTerminals();
  }

  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        fab: loading
            ? const SizedBox()
            : RavenPayFab(
                buttonColor:
                    canRequestTerminal ? null : pluginTheme.secondaryColor,
                onPressed: () {
                  // can not request terminal except affliate info is found
                  if (affiliateInfo == null) {
                    final error = BankBoxException(
                        code: kAffliateUpdateError,
                        message: 'App settings missing');
                    pluginConfig.onError(error);
                    return;
                  }
                  if (!canRequestTerminal) {
                    showRavenPayBottomSheet(context,
                        child: const PendingTerminalRequestSheet());

                    return;
                  }

                  pushRoute(
                      context,
                      RequestPosIndex(
                        updateUserInfo: updateBusinessInfo,
                      ));
                },
                widget: Row(mainAxisSize: MainAxisSize.min, children: [
                  canRequestTerminal
                      ? Icon(Icons.add, color: pluginTheme.onPrimary)
                      : Image.asset(loadAsset("pending_icon.png"), height: 20),
                  const Gap(4),
                  Text(
                    canRequestTerminal
                        ? "Request Terminal"
                        : "Pending Delivery",
                    style: subtitle.copyWith(
                        fontSize: 14, color: pluginTheme.onPrimary),
                  ),
                ]),
              ),
        body: Column(children: [
          Padding(
              padding:
                  EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
              child: Column(
                children: [
                  const Gap(24),
                  const RavenPayCloseButton(
                    text: "",
                    isArrow: true,
                  ),
                  const Gap(24),
                  Align(
                    alignment: Alignment.centerLeft,
                    child: Text(
                      "All Terminals",
                      style: headling1,
                    ),
                  ),
                  if (allTerminals.isNotEmpty) ...[
                    const Gap(16),
                    Text(
                        "Manage all your terminals here, request, edit and track all at the same time.",
                        style: subtitle2.copyWith(fontSize: 14)),
                  ],
                ],
              )),
          const Gap(12),
          Expanded(
            child: loading == true
                ? Center(
                    child: RavenButtonLoader(
                      size: 18,
                      color: pluginConfig.theme!.primaryColor,
                    ),
                  )
                : allTerminals.isEmpty
                    ? Center(
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.center,
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Container(
                                margin:
                                    const EdgeInsets.symmetric(vertical: 10),
                                padding: const EdgeInsets.all(20),
                                decoration: BoxDecoration(
                                  color: AppColors.ravenGrey4,
                                  borderRadius: BorderRadius.circular(60),
                                ),
                                child: Image.asset(loadAsset("mpos_image.png"),
                                    height: 70)),
                            const Gap(20),
                            Text(
                              "No terminals found",
                              style: headling1.copyWith(fontSize: 18),
                              textAlign: TextAlign.center,
                            ),
                            const Gap(8),
                            Padding(
                              padding:
                                  const EdgeInsets.symmetric(horizontal: 32),
                              child: Text(
                                "You do not have any terminals attached to your account, request a tereminal with the buttom below to see them here.",
                                style: subtitle2.copyWith(fontSize: 14),
                                textAlign: TextAlign.center,
                              ),
                            ),
                            Gap(MediaQuery.of(context).size.height / 8),
                          ],
                        ),
                      )
                    : RefreshIndicator(
                        color: pluginTheme.primaryColor,
                        onRefresh: () async {
                          await Future.delayed(const Duration(seconds: 2));
                          fetchTerminals(showLoading: false);
                        },
                        child: ListView.builder(
                            padding: EdgeInsets.symmetric(
                                    horizontal: kHorizontalScreenPadding) +
                                const EdgeInsets.only(top: 4),
                            itemCount: allTerminals.length,
                            itemBuilder: (context, index) {
                              final terminal = allTerminals[index];
                              return terminal is TerminalModel
                                  ? BankBoxTerminalItemWidget(
                                      // onlabelUpdated: () {
                                      //   fetchTerminals();
                                      // },
                                      terminal: terminal,
                                    )
                                  : terminal is TerminalRequestModel &&
                                          terminal.status != 4
                                      ? TerminalRequestItem(model: terminal)
                                      : const SizedBox();
                            }),
                      ),
          )
        ]));
  }
}

==> mobile_pos-2.0.0.tar.gz: lib/src/views/terminal/view_all_terminal_index.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/mobile_pos_sdk.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/raven_pay_fab.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button_loader.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/request_pos_index.dart';
import 'package:mobile_pos/src/views/terminal/widget/new_terminal_item.dart';
import 'package:mobile_pos/src/views/terminal/widget/pending_terminal_request_sheet.dart';
import 'package:mobile_pos/src/views/terminal/widget/terminal_item.dart';

class ViewAllTerminalIndex extends StatefulWidget {
  const ViewAllTerminalIndex({super.key});

  @override
  State<ViewAllTerminalIndex> createState() => _ViewAllTerminalIndexState();
}

class _ViewAllTerminalIndexState extends State<ViewAllTerminalIndex> {
  bool loading = true;
  List<Terminal> allTerminals = [];
  bool canRequestTerminal = true;
  bool updateBusinessInfo = false;

  void fetchTerminals({bool showLoading = true}) async {
    allTerminals.clear();
    if (showLoading) {
      loading = true;
    } else {
      loading = false;
    }
    updateBusinessInfo = await ApiRequests.getKYBStatus();
    await ApiRequests.fetchAppInfo();
    if (!mounted) {
      return;
    }
    final res = await ApiRequests.getUserBankBox();
    allTerminals.addAll(res);

    final res2 = await ApiRequests.getUserTerminalRequests();
    if (!mounted) {
      return;
    }
    canRequestTerminal = res2.isEmpty;
    allTerminals.addAll(res2);
    loading = false;
    setState(() {});
  }

  @override
  void initState() {
    super.initState();
    fetchTerminals();
  }

  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        fab: loading
            ? const SizedBox()
            : RavenPayFab(
                buttonColor:
                    canRequestTerminal ? null : pluginTheme.secondaryColor,
                onPressed: () {
                  // can not request terminal except affliate info is found
                  if (affiliateInfo == null) {
                    final error = BankBoxException(
                        code: kAffliateUpdateError,
                        message: 'App settings missing');
                    pluginConfig.onError(error);
                    return;
                  }
                  if (!canRequestTerminal) {
                    showRavenPayBottomSheet(context,
                        child: const PendingTerminalRequestSheet());

                    return;
                  }

                  pushRoute(
                      context,
                      RequestPosIndex(
                        updateUserInfo: updateBusinessInfo,
                      ));
                },
                widget: Row(mainAxisSize: MainAxisSize.min, children: [
                  canRequestTerminal
                      ? Icon(Icons.add, color: pluginTheme.onPrimary)
                      : Image.asset(loadAsset("pending_icon.png"), height: 20),
                  const Gap(4),
                  Text(
                    canRequestTerminal
                        ? "Request Terminal"
                        : "Pending Delivery",
                    style: subtitle.copyWith(
                        fontSize: 14, color: pluginTheme.onPrimary),
                  ),
                ]),
              ),
        body: Column(children: [
          Padding(
              padding:
                  EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
              child: Column(
                children: [
                  const Gap(24),
                  const RavenPayCloseButton(
                    text: "",
                    isArrow: true,
                  ),
                  const Gap(24),
                  Align(
                    alignment: Alignment.centerLeft,
                    child: Text(
                      "All Terminals",
                      style: headling1,
                    ),
                  ),
                  if (allTerminals.isNotEmpty) ...[
                    const Gap(16),
                    Text(
                        "Manage all your terminals here, request, edit and track all at the same time.",
                        style: subtitle2.copyWith(fontSize: 14)),
                  ],
                ],
              )),
          const Gap(12),
          Expanded(
            child: loading == true
                ? Center(
                    child: RavenButtonLoader(
                      size: 18,
                      color: pluginConfig.theme!.primaryColor,
                    ),
                  )
                : allTerminals.isEmpty
                    ? Center(
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.center,
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Container(
                                margin:
                                    const EdgeInsets.symmetric(vertical: 10),
                                padding: const EdgeInsets.all(20),
                                decoration: BoxDecoration(
                                  color: AppColors.ravenGrey4,
                                  borderRadius: BorderRadius.circular(60),
                                ),
                                child: Image.asset(loadAsset("mpos_image.png"),
                                    height: 70)),
                            const Gap(20),
                            Text(
                              "No terminals found",
                              style: headling1.copyWith(fontSize: 18),
                              textAlign: TextAlign.center,
                            ),
                            const Gap(8),
                            Padding(
                              padding:
                                  const EdgeInsets.symmetric(horizontal: 32),
                              child: Text(
                                "You do not have any terminals attached to your account, request a tereminal with the buttom below to see them here.",
                                style: subtitle2.copyWith(fontSize: 14),
                                textAlign: TextAlign.center,
                              ),
                            ),
                            Gap(MediaQuery.of(context).size.height / 8),
                          ],
                        ),
                      )
                    : RefreshIndicator(
                        color: pluginTheme.primaryColor,
                        onRefresh: () async {
                          await Future.delayed(const Duration(seconds: 2));
                          fetchTerminals(showLoading: false);
                        },
                        child: ListView.builder(
                            padding: EdgeInsets.symmetric(
                                    horizontal: kHorizontalScreenPadding) +
                                const EdgeInsets.only(top: 4),
                            itemCount: allTerminals.length,
                            itemBuilder: (context, index) {
                              final terminal = allTerminals[index];
                              return terminal is TerminalModel
                                  ? BankBoxTerminalItemWidget(
                                      // onlabelUpdated: () {
                                      //   fetchTerminals();
                                      // },
                                      terminal: terminal,
                                    )
                                  : terminal is TerminalRequestModel
                                      ? TerminalRequestItem(model: terminal)
                                      : const SizedBox();
                            }),
                      ),
          )
        ]));
  }
}
